/* 
Function that converts input data to a string
Handles named and unnamed objects and groups. Requires Fwatch 1.15 and FindInArray_OFPCWA.sqf
Has to be called through Convert_AllObj_To_String_Init.sqf
by Faguss (ofp-faguss.com) 09.07.21

Usage:
	IS_CWA                        = Format ["%1",getworld]!="scalar bool array string 0xfcffffef"
	FindInArray_OFPCWA            = preProcessFile "FindInArray_OFPCWA.sqf"
	CONVERT_ALLOBJ_TO_STRING_INIT = preProcessFile "Convert_AllObj_To_String_Init.sqf"
	CONVERT_ALLOBJ_TO_STRING      = preProcessFile "Convert_AllObj_To_String.sqf"
	[<data>, <named units>] call CONVERT_ALLOBJ_TO_STRING_INIT

Example:
	[[soldier1,player,(object 1244)], ["soldier1","soldier2","soldier3"]] call CONVERT_ALLOBJ_TO_STRING_INIT
*/

private ["_string", "_index"];

// if scalar
if ((_this select 0) in [(_this select 0)]) then {

	// if string
	if ((_this select 0) in [Format["%1",(_this select 0)]]) then {
		"{" + (_this select 0) + "}"
	} else {
		
		// if boolean / side
		if ((_this select 0) in [west,east,resistance,civilian,logic,enemy,true,false]) then {
			Format ["%1",(_this select 0)]
		} else {
		
			// if number
			if (loadFile Format ["\:STRING ISNUMBER text:%1",(_this select 0)] != "string") then {
				Format ["%1",(_this select 0)]
			} else {
			
				// if not objNull / grpNull
				if ((_this select 0) == (_this select 0)) then {
				
					// if named object
					_index = [(_this select 0),(_this select 2)] call FindInArray_OFPCWA;
					if (_index >= 0) then {
						(_this select 1) select _index
					} else {
					
						// if object
						if ("_x=={:} || _x=={#}" count (call loadFile Format ["\:STRING SPLIT text:%1",(_this select 0)]) > 0) then {
							Format ["nearestObject [%1,""%2""]", getPos (_this select 0), typeOf (_this select 0)]
						} else {
							
							// if named group
							_index = [(_this select 0),(_this select 3)] call FindInArray_OFPCWA;
							if (_index >= 0) then {
								"group " + ((_this select 1) select _index)
							} else {
							
								// if group
								Format ["group nearestObject [%1,""%2""]", getPos (units (_this select 0) select 0), typeOf (units (_this select 0) select 0)]
							}
						}
					}
				} else {
				
					// if objNull / grpNull
					if (Format ["%1",(_this select 0)] == "<NULL-group>") then {
						"grpNull"
					} else {
						"objNull"
					}
				}
				
			}
			
		}

	}
} else {

	// if array
	_string = "[";
	{_string = _string + "]+[" + ([_x, (_this select 1), (_this select 2), (_this select 3)] call CONVERT_ALLOBJ_TO_STRING)} forEach (_this select 0);
	_string + "]"
}